====================
BrainSpace
====================


.. image:: https://github.com/MICA-MNI/brainspace/workflows/Python%20package/badge.svg
   :target: https://github.com/MICA-MNI/brainspace/actions

.. image:: https://codecov.io/gh/mica-mni/brainspace/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/mica-mni/brainspace

.. image:: https://img.shields.io/appveyor/build/OualidBenkarim/brainspace/master?logo=appveyor
   :alt: AppVeyor branch

.. image:: https://img.shields.io/pypi/v/brainspace
   :target:  https://pypi.python.org/pypi/brainspace

.. image:: https://img.shields.io/pypi/l/brainspace?label=License
   :target: https://opensource.org/licenses/BSD-3-Clause

.. image:: https://img.shields.io/pypi/pyversions/brainspace
   :alt: PyPI - Python Version

BrainSpace is a lightweight cross-platform toolbox primarily intended 
for macroscale gradient mapping and analysis of 
neuroimaging and connectome level data. The current version 
of BrainSpace is available in Python and MATLAB, programming 
languages widely used by the neuroimaging and network neuroscience 
communities. The toolbox also contains several maps that allow for 
exploratory analysis of gradient correspondence with other 
brain-derived features, together with tools to generate spatial null models.

For installation instructions, examples and documentation of BrainSpace see
our `documentation <https://brainspace.readthedocs.io>`_.

Happy gradient analysis! 

License
-----------

The BrainSpace source code is available under the BSD (3-Clause) license.

Support
-----------

If you have problems installing the software or questions about usage 
and documentation, or something else related to BrainSpace, 
you can post to the Issues section of our `repository <https://github.com/MICA-MNI/BrainSpace/issues>`_.

Paper
-----------

If you consider using BrainSpace, please cite our manuscript: 
Vos de Wael R, Benkarim O, Paquola C, Lariviere S, Royer J, Tavakol S, Xu T, Hong S, Langs G, Valk S, Misic B, Milham M, Margulies D, Smallwood J, Bernhardt B (2020). BrainSpace: a toolbox for the analysis of macroscale gradients in neuroimaging and connectomics datasets. Commun Biol 3, 103.

Core development team
-----------------------

* Reinder Vos de Wael, MICA Lab - Montreal Neurological Institute
* Oualid Benkarim, MICA Lab - Montreal Neurological Institute
* Boris Bernhardt, MICA Lab - Montreal Neurological Institute

